@@ -32,10 +32,12 @@ from splitgraph.__version__ import __version__
 from splitgraph.cloud.models import (
     AddExternalCredentialRequest,
     AddExternalRepositoriesRequest,
+    AddExternalRepositoriesResponse,
     AddExternalRepositoryRequest,
     ExportJobStatus,
     ExternalResponse,
     IngestionJobStatus,
+    IntrospectionMode,
     ListExternalCredentialsResponse,
     MetadataResponse,
     Plugin,
@@ -74,6 +76,7 @@ from splitgraph.config.export import overwrite_config
 from splitgraph.config.management import patch_and_save_config
 from splitgraph.exceptions import (
     AuthAPIError,
+    DataSourceError,
     GQLAPIError,
     GQLRepoDoesntExistError,
     GQLUnauthenticatedError,
@@ -530,15 +533,37 @@ class RESTAPIClient:
                 raise JSONSchemaValidationError(message="[MASKED]")
             raise
 
-    def bulk_upsert_external(self, repositories: List[AddExternalRepositoryRequest]):
-        request = AddExternalRepositoriesRequest(repositories=repositories)
-        self._perform_request(
+    def bulk_upsert_external(
+        self,
+        repositories: List[AddExternalRepositoryRequest],
+        introspection_mode: IntrospectionMode = IntrospectionMode.EMPTY,
+        raise_errors: bool = False,
+    ) -> None:
+        request = AddExternalRepositoriesRequest(
+            repositories=repositories, introspection_mode=introspection_mode
+        )
+        response = self._perform_request(
             "/bulk-add",
             self.access_token,
             request,
             endpoint=self.externals_endpoint,
             jsonschema_endpoint=True,
+            response_class=AddExternalRepositoriesResponse,
         )
+        assert response
+        if response.errors:
+            for repo_errors in response.errors:
+                for error in repo_errors.errors:
+                    logging.warning(
+                        "Error adding table %s/%s/%s: %s (%s)",
+                        repo_errors.namespace,
+                        repo_errors.repository,
+                        error.table_name,
+                        error.error,
+                        error.error_text,
+                    )
+            if raise_errors:
+                raise DataSourceError("Error introspecting some tables!")
 
 
 def AuthAPIClient(*args, **kwargs):
@@ -948,9 +973,9 @@ class GQLAPIClient:
             supports_mount=plugin_dict["supportsMount"],
         )
 
-    def get_all_plugins(self) -> List[Plugin]:
+    def get_all_plugins(self, seed: Optional[str] = None) -> List[Plugin]:
         response = self._gql(
-            {"query": GET_PLUGINS, "operationName": "ExternalPlugins"},
+            {"query": GET_PLUGINS, "operationName": "ExternalPlugins", "variables": {"seed": seed}},
             handle_errors=True,
             anonymous_ok=True,
         )
